The proportion of GC in the target genome in an alignment. For the same on the query genome, just transpose the input matrix.
Arguments
- m
A matrix of counts or probabilities for bases of the target genome to be aligned to bases on the query genome. As a convenience it can also receive a list produced by the
readTrainFile()function, containing this matrix.
Examples
GCproportion(exampleSubstitutionMatrix)
#> [1] 0.4347341
GCproportion(t(exampleSubstitutionMatrix))
#> [1] 0.4302136