Skip to contents

This function transforms a permutation with N elements into a permutation with 2N elements. The idea is that each element in the input permutation corresponds to an aligned block (or gene, conserved region, etc.). This function creates two elements for each original element: one representing the start of the block and the other representing the end.

Usage

extendedPermutation(p)

Arguments

p

A signed permutation vector.

Value

The extended permutation.

Author

Bruna Fistarol