The Jukes and Cantor 1969 (JC69) distance is calculated as \(-\frac{3}{4} \ln(1 - \frac{4}{3} p )\), where \(p\) is the sum of the probabilities of the alignment. See the Wikipedia for more details.
Arguments
- m
Two possible types of input are available:
A matrix of counts or probabilities for bases of the target genome to be aligned to bases on the query genome;
The mismatch count (a positive integer) or proportion (a number between
0.0and1.0).
- tot
The total count of nucleotides, in case the parameter
mis the count of mismatches.- adjust_p
A boolean flag. If
TRUE, the distance is scaled between0and0.75to ensure the logarithm stays positive.
Value
Returns a numeric value representing the evolutionary distance between two genomes. The greater the value, the more genetically different the genomes are.
References
Jukes, T.H. & Cantor, C.R. (1969). "Evolution of protein molecules." In Mammalian Protein Metabolism (pp. 21–132). Academic Press.
See also
Other Alignment statistics:
F81_distance(),
GCequilibrium(),
GCpressure(),
GCproportion(),
HKY85_distance(),
K80_distance(),
K80_gap_distance(),
P_distance(),
T92_distance(),
TN93_distance(),
exampleSubstitutionMatrix,
gapProportion(),
logDet_distance()
Other Similarity indexes:
F81_distance(),
GOC(),
HKY85_distance(),
K80_distance(),
K80_gap_distance(),
P_distance(),
T92_distance(),
TN93_distance(),
breakpointGraphProperties(),
correlation_index(),
inversionDistance(),
inversionEstimate_BD(),
karyotype_index(),
logDet_distance(),
slidingWindow(),
strand_randomisation_index(),
synteny_index(),
tau_index()