Computes the breakpoint graph of a pair of chromosomes and returns key properties of the graph, which are used in various rearrangement estimates.
Arguments
- gb
A
GBreaksobject.
Value
A list containing the following properties of the breakpoint graph:
1. N : the total number of places where a breakpoint could occur (which is the same as the number_aligned_blocks + 1);
2. nbBreakpoints : the total number of breakpoints in the extended permutation;
3. nbCycles : the total number of cycles in the breakpoint graph.
References
Hannenhalli, Sridhar, and Pavel A. Pevzner. "Transforming cabbage into turnip: polynomial algorithm for sorting signed permutations by reversals." Journal of the ACM (JACM) 46.1 (1999): 1-27.
See also
Other Breakpoint graph functions:
bp_count(),
breakpoint_graph(),
components_graph(),
cycle_count(),
extendedPermutation(),
hurdles_count(),
is_fortress(),
is_interleaving(),
superhurdles_count()
Other Rearrangement distances:
inversionDistance(),
inversionEstimate_BD()
Other Similarity indexes:
F81_distance(),
GOC(),
HKY85_distance(),
JC69_distance(),
K80_distance(),
K80_gap_distance(),
P_distance(),
T92_distance(),
TN93_distance(),
correlation_index(),
inversionDistance(),
inversionEstimate_BD(),
karyotype_index(),
logDet_distance(),
slidingWindow(),
strand_randomisation_index(),
synteny_index(),
tau_index()