This function transforms a permutation with N elements into a permutation with 2N elements.
The idea is that each element in the input permutation corresponds to an aligned block (or gene, conserved region, etc.).
This function creates two elements for each original element: one representing the start of the block and the other representing the end.
See also
Other Breakpoint graph functions:
bp_count(),
breakpointGraphProperties(),
breakpoint_graph(),
components_graph(),
cycle_count(),
hurdles_count(),
is_fortress(),
is_interleaving(),
superhurdles_count()