Check whether or not the permutation is a fortress. A permutation is a fortress if the number of hurdles is odd and all hurdles are superhurdles.
See also
Other Breakpoint graph functions:
bp_count(),
breakpointGraphProperties(),
breakpoint_graph(),
components_graph(),
cycle_count(),
extendedPermutation(),
hurdles_count(),
is_interleaving(),
superhurdles_count()